<?php

declare(strict_types=1);

namespace Silex\Controller;

use Silex\DI\DI;
use Silex\Http\HttpResponse;
use Silex\Util\Pagination;

class UserController
{
    private const PER_PAGE = 12;

    public function index(DI $di, array $params): HttpResponse
    {
        $gw = $di->getNewsGateway();

        $page = intval($params['page'] ?? 1);
        $total = $gw->getCount();
        $nbPages = Pagination::getNbPages($total, self::PER_PAGE);
        $news = $gw->getPaginatedRecentNews($page , self::PER_PAGE);
        return new HttpResponse(200, 'home', ['news' => $news, 'page' => $page, 'nbPages' => $nbPages]);
    }

    public function viewPost(DI $di, array $params): HttpResponse
    {
        $newsId = intval($params['id']);
        $news = $di->getNewsGateway()->getById($newsId);
        return new HttpResponse(200, 'newsView', ['news' => $news]);
    }

    public function viewPostComments(DI $di, array $params): HttpResponse
    {
        $newsId = intval($params['id']);
        $comments = $di->getCommentGateway()->getByNewsId($newsId);
        return new HttpResponse(200, 'comment', ['comments' => $comments]);
    }
}
